#include "stealth.ih"

void Stealth::parentProcess()
{}

